@@ -26,7 +26,7 @@ class PublicKey(key.Key):
     """This class represents public keys."""
 
     def __init__(self, algorithm, bit_length, key,
-                 name=None, created=None, id=None):
+                 name=None, created=None, id=None, consumers=[]):
         """Create a new PublicKey object.
 
         The arguments specify the algorithm and bit length for the asymmetric
@@ -36,25 +36,26 @@ class PublicKey(key.Key):
         self._alg = algorithm
         self._bit_length = bit_length
         self._key = key
-        super(PublicKey, self).__init__(name=name, created=created, id=id)
+        super().__init__(name=name, created=created, id=id,
+                         consumers=consumers)
+
+    @classmethod
+    def managed_type(cls):
+        return "public"
 
     @property
     def algorithm(self):
-        """Returns the algorithm for asymmetric encryption."""
         return self._alg
 
     @property
     def format(self):
-        """This method returns 'SubjectPublicKeyInfo'."""
         return "SubjectPublicKeyInfo"
 
     def get_encoded(self):
-        """Returns the key in its encoded format."""
         return self._key
 
     @property
     def bit_length(self):
-        """Returns the key length."""
         return self._bit_length
 
     def __eq__(self, other):
